# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
#          Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The user interface for the Ubuntu One Installer."""

import subprocess

from PyQt4 import QtGui

from ubuntuone_installer.logger import setup_logging
from ubuntuone_installer.gui.qt.ui import (
    license_ui,
    congratulations_ui
    )

import gettext

_ = gettext.gettext

# Invalid name logger
# pylint: disable=C0103
logger = setup_logging('qt.gui')
# pylint: enable=C0103


class LicensePage(QtGui.QWizardPage):
    """Wizard Page that displays the license info and links to the GPL"""

    def __init__(self, parent=None):
        QtGui.QWizardPage.__init__(self, parent)
        self.page_ui = license_ui.Ui_Form()
        self.page_ui.setupUi(self)

    # Invalid names of Qt-inherited methods
    # pylint: disable=C0103
    
    def initializePage(self):
        """Setup UI details"""

        # We need custom buttons
        self.wizard().setButtonText(QtGui.QWizard.CustomButton1, _("&Print"))
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, True)

        # Set the right texts and connections for buttons
        self.setButtonText(QtGui.QWizard.NextButton, _("Agree && Install"))
        self.setButtonText(QtGui.QWizard.CancelButton,
            _("Disagree && Cancel"))        
        self.setButtonText(QtGui.QWizard.CustomButton1, _("&Print"))        
        self.wizard().customButtonClicked.connect(self.printDocument)
        
    def printDocument(self, button_id):
        """Print the document displayed in textBrowser"""
        
        if button_id == QtGui.QWizard.CustomButton1:
            document = self.page_ui.textBrowser.document()
            printer = QtGui.QPrinter(QtGui.QPrinter.HighResolution)

            dialog = QtGui.QPrintDialog(printer, self)
            
            dialog.setWindowTitle(_("Send to printer"))
            if dialog.exec_() != QtGui.QDialog.Accepted:
                return
            printer.setFullPage(True)
            printer.setPageSize(QtGui.QPrinter.A4)
            document.print_(printer)


class CongratulationsPage(QtGui.QWizardPage):
    """Final page of the wizard"""
    
    def __init__(self, parent=None):
        QtGui.QWizardPage.__init__(self, parent)
        self.page_ui = congratulations_ui.Ui_Form()
        self.page_ui.setupUi(self)
        
    # Invalid names of Qt-inherited methods
    # pylint: disable=C0103

    def initializePage(self):
        """Setup UI details"""

        # We need custom buttons
        self.wizard().setButtonText(QtGui.QWizard.FinishButton, 
            _("Go to my Ubuntu One dashboard"))
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, False)        
        self.wizard().setOption(QtGui.QWizard.NoCancelButton, True)
        
class MainWindow(QtGui.QWizard):
    """The Main Window of the Installer wizard."""

    # Invalid constant names and Qt-inherited methods
    # pylint: disable=C0103
    
    LICENSE_PAGE = 0
    CONGRATULATIONS_PAGE = 1
    
    def __init__(self, close_callback=None):
        """Initialize this instance with the UI layout."""
        
        QtGui.QWizard.__init__(self)
        self.close_callback = close_callback

        self.setOption(self.NoBackButtonOnStartPage, True)
        self.setOption(self.DisabledBackButtonOnLastPage, True)
        # PyQt doesn't support the (int, page) version of addPage
        # Add the pages in the right order
        
        # pylint: disable=C0103
        self.LICENSE_PAGE = self.addPage(LicensePage())
        self.CONGRATULATIONS_PAGE = self.addPage(CongratulationsPage())

    # Invalid name "closeEvent"
    # pylint: disable=C0103

    def done(self, result):
        """The main window is being closed, call any custom callback."""
        if result == 1: # Finished, not cancelled
            subprocess.Popen(["ubuntuone-control-panel-gtk",])
        if self.close_callback is not None:
            self.close_callback()
        QtGui.QWizard.done(self, result)
